==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_texteditor/l10n/lt_LT.js <==
OC.L10N.register(
    "files_texteditor",
    {
    "saving..." : "saugoma...",
    "saved!" : "Išsaugota!",
    "failed!" : "nepavyko!",
    "Saved" : "Įrašyta",
    "There was a problem saving your changes. Click to resume editing." : "Klaida išsaugant pakeitimus. Paspauskite redagavimo tęsimui.",
    "An error occurred!" : "Įvyko klaida!",
    "Edit" : "Redaguoti",
    "Mixed" : "Įvairūs",
    "Preview" : "Peržiūra",
    "New text file" : "Naujas tekstinis failas",
    "New text file.txt" : "Naujas tekstinis failas.txt",
    "You can not open a folder" : "Jūs negalite atverti aplanko",
    "This file is too big to be opened. Please download the file instead." : "Šis failas yra per didelis, kad būtų atvertas. Vietoj to, prašome jį atsisiųsti.",
    "Cannot read the file." : "Nepavyko perskaityti failo.",
    "Invalid file path supplied." : "Pateiktas neteisingas failo kelias.",
    "The file is locked." : "Failas užrakintas.",
    "An internal server error occurred." : "Įvyko vidinė serverio klaida.",
    "You can not write to a folder" : "Negalima rašyti į aplanką",
    "Cannot save file as it has been modified since opening" : "Negalima išsaugoti failo, nes jis pakeistas po atidarymo",
    "Insufficient permissions" : "Nepakanka leidimų",
    "File path not supplied" : "Nepateiktas failo kelias",
    "File mtime not supplied" : "Failo modifikavimo laikas nepateiktas",
    "Text editor" : "Tekstų redaktorius",
    "Text file" : "Tekstinis failas"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_texteditor/l10n/lt_LT.js <==
OC.L10N.register(
    "files_texteditor",
    {
    "saving..." : "įrašoma...",
    "saved!" : "įrašyta!",
    "failed!" : "nepavyko!",
    "Saved" : "Įrašyta",
    "There was a problem saving your changes. Click to resume editing." : "Klaida įrašant pakeitimus. Spustelėkite, norėdami tęsti redagavimą.",
    "An error occurred!" : "Įvyko klaida!",
    "Edit" : "Redaguoti",
    "Mixed" : "Įvairūs",
    "Preview" : "Peržiūra",
    "New text file" : "Naujas tekstinis failas",
    "New text file.txt" : "Naujas tekstinis failas.txt",
    "You can not open a folder" : "Jūs negalite atverti aplanko",
    "This file is too big to be opened. Please download the file instead." : "Šis failas yra per didelis, kad būtų atvertas. Vietoj to, prašome jį atsisiųsti.",
    "Cannot read the file." : "Nepavyko perskaityti failo.",
    "Invalid file path supplied." : "Pateiktas neteisingas failo kelias.",
    "The file is locked." : "Failas užrakintas.",
    "An internal server error occurred." : "Įvyko vidinė serverio klaida.",
    "You can not write to a folder" : "Negalima rašyti į aplanką",
    "Cannot save file as it has been modified since opening" : "Negalima išsaugoti failo, nes jis pakeistas po atidarymo",
    "Insufficient permissions" : "Nepakanka leidimų",
    "File path not supplied" : "Nepateiktas failo kelias",
    "File mtime not supplied" : "Failo modifikavimo laikas nepateiktas",
    "Text editor" : "Tekstų redaktorius"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
